==> haskell-warp-3.3.13-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.13
visibility:           public
id:                   warp-3.3.13-CTgQxaflkBC3feDCVJ4KkD
key:                  warp-3.3.13-CTgQxaflkBC3feDCVJ4KkD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  94118d1771c756b5224881369628f9eb
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
    Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
    Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-8.10.2/site-local/warp-3.3.13
library-dirs:         /usr/lib/ghc-8.10.2/site-local/warp-3.3.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/warp-3.3.13
hs-libraries:         HSwarp-3.3.13-CTgQxaflkBC3feDCVJ4KkD
depends:
    array-0.5.4.0 async-2.2.2-4opYcauw8BY2AHRxRWO8u0
    auto-update-0.1.6-3jx19J8AsGd3X7FsnL44xj base-4.14.1.0
    bsb-http-chunked-0.0.0.4-Dd7m8NNnjBG9iuuS0oPnkD
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-FmVDobnlpkqAs7UbcUCZtp containers-0.6.2.1
    ghc-prim-0.6.1 hashable-1.3.0.0-B8ECnPmIwukCF0VUFUS7Nf
    http-date-0.0.9-4vgvw32NTefEt6MWwcla2l
    http-types-0.12.3-7MVILbrPwKk8q79RIPT2pO
    http2-2.0.5-4FzFiaCWCVSAd4m44ozYkv
    iproute-1.7.9-8Be5RxsqhTG2bvR94k6yOb
    network-3.1.2.0-EVsJVplm5cL2hwQQOqkE2a
    simple-sendfile-0.2.30-Aa6TudvfgDIGAXzfol3uZc stm-2.5.0.0
    streaming-commons-0.2.2.1-5x1twxarxm3CdMqxxfvnv text-1.2.3.2
    time-manager-0.0.0-389zkpodypUHEBhCEImv7T unix-2.7.2.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    vault-0.3.1.4-KQAoA9uik8U8OMgkFBaDue
    wai-3.2.2.1-txMDMPPmzeA5z8LFy4S9l
    word8-0.1.3-724fxDOkAtI9odHi3S4RPp
    x509-1.7.5-7LFq4F3yjhYBJpgoVuWjOu

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.3.13-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.13
visibility:           public
id:                   warp-3.3.13-FnSWhrXZSq1LvrCWXKVoUu
key:                  warp-3.3.13-FnSWhrXZSq1LvrCWXKVoUu
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  799301d184dad2854abe51682694251c
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
    Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
    Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-8.10.2/site-local/warp-3.3.13
library-dirs:         /usr/lib/ghc-8.10.2/site-local/warp-3.3.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/warp-3.3.13
hs-libraries:         HSwarp-3.3.13-FnSWhrXZSq1LvrCWXKVoUu
depends:
    array-0.5.4.0 async-2.2.2-KsABh1Xq3KKHTwRj3PM458
    auto-update-0.1.6-EcywLtX96mZ1AxhVR3sOs4 base-4.14.1.0
    bsb-http-chunked-0.0.0.4-6su0sCrR7HO1zCYOJL0Abd
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-HouKk9k640X8DZj3LUmWDh containers-0.6.2.1
    ghc-prim-0.6.1 hashable-1.3.0.0-Knba2WADhucBBNEV6vFhdj
    http-date-0.0.9-H60PkcMIxndKdyrWc1hHRx
    http-types-0.12.3-1IpGyMozZPuEoZlnKpzRlk
    http2-2.0.5-K2hf3FMMA1NINUylBHwNZO
    iproute-1.7.9-KtU5ZzHMrO2Luk6XYxPIfe
    network-3.1.2.0-6JDKfAnmzxBDIIJL2Fi5PT
    simple-sendfile-0.2.30-3iilUNrmg5xBBI9X5gfKaQ stm-2.5.0.0
    streaming-commons-0.2.2.1-4PybeQ4anAZJoFRkLyS3ZI text-1.2.3.2
    time-manager-0.0.0-JMwboVcvEHXB7Ne5qE1iLB unix-2.7.2.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    vault-0.3.1.4-2UId8A5mdmIlI0wJAvNoy
    wai-3.2.2.1-E36OGtd5WDC8tLR9JdbO1M
    word8-0.1.3-724fxDOkAtI9odHi3S4RPp
    x509-1.7.5-HuPIl0SErZEBHvTiyo5deD

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
